@@ -2,10 +2,7 @@
 
 package Dancer::Plugin::DBIC;
 BEGIN {
-  $Dancer::Plugin::DBIC::VERSION = '0.14';
-}
-BEGIN {
-  $Dancer::Plugin::DBIC::VERSION = '0.14';
+  $Dancer::Plugin::DBIC::VERSION = '0.15';
 }
 
 use strict;
@@ -14,35 +11,41 @@ use Dancer::Plugin;
 use DBIx::Class;
 use DBIx::Class::Schema::Loader;
 
-my  $cfg = plugin_setting;
-my  $schemas = {};
 
+my $cfg = plugin_setting;
+my $schemas = {};
 
-foreach my $keyword (keys %{ $cfg }) {
-    register $keyword => sub {
-        return $schemas->{$keyword} if $schemas->{$keyword};
-        
-        my @dsn = $cfg->{$keyword}->{connect_info}
-            ? @{$cfg->{$keyword}{connect_info}}
-            : @{$cfg->{$keyword}}{qw(dsn user pass options)};
+register schema => sub {
+    my $name = shift;
 
-        my $schema_class = $cfg->{$keyword}{schema_class}
-            || $cfg->{$keyword}{pckg}; # pckg should be deprecated
+    if (defined $name) {
+        return $schemas->{$name} if $schemas->{$name};
+    } else {
+        ($name) = keys %$cfg or die "No schemas are configured";
+    }
 
-        if ($schema_class) {
-            $schema_class =~ s/-/::/g;
-            eval "use $schema_class";
-            if ( my $err = $@ ) {
-                die "error while loading $schema_class : $err";
-            }
-            $schemas->{$keyword} = $schema_class->connect(@dsn)
-        } else {
-            $schemas->{$keyword} = DBIx::Class::Schema::Loader->connect(@dsn);
+    my $options = $cfg->{$name} or die "The schema $name is not configured";
+
+    my @conn_info = $options->{connect_info}
+        ? @{$options->{connect_info}}
+        : @$options{qw(dsn user pass options)};
+
+    # pckg should be deprecated
+    my $schema_class = $options->{schema_class} || $options->{pckg};
+
+    if ($schema_class) {
+        $schema_class =~ s/-/::/g;
+        eval "use $schema_class";
+        if ( my $err = $@ ) {
+            die "error while loading $schema_class : $err";
         }
-        
-        return $schemas->{$keyword};
-    };
-}
+        $schemas->{$name} = $schema_class->connect(@conn_info)
+    } else {
+        $schemas->{$name} = DBIx::Class::Schema::Loader->connect(@conn_info);
+    }
+
+    return $schemas->{$name};
+};
 
 register_plugin;
 
@@ -57,79 +60,69 @@ Dancer::Plugin::DBIC - DBIx::Class interface for Dancer applications
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
+    # Dancer Code File
+    use Dancer;
+    use Dancer::Plugin::DBIC;
+    #use Dancer::Plugin::DBIC qw(schema); # explicit import
+
+    get '/profile/:id' => sub {
+        my $user = schema->resultset('Users')->find(params->{id});
+        # or explicitly ask for a schema by name:
+        $user = schema('foo')->resultset('Users')->find(params->{id});
+        template user_profile => { user => $user };
+    };
+
+    dance;
+
     # Dancer Configuration File
     plugins:
       DBIC:
         foo:
           dsn:  "dbi:SQLite:dbname=./foo.db"
-        bar:
-          dsn:  "dbi:mysql:db_foo"
-          user: "root"
-          pass: "****"
-          options:
-            RaiseError: 1
-            PrintError: 1
-    
-    # Dancer Code File
-    use Dancer;
-    use Dancer::Plugin::DBIC;
-
-    # Calling foo or bar will return a DBIx::Class::Schema instance using
-    # the database connection info from the configuration file.
-    
-    get '/profile/:id' => sub {
-        my $user = foo->resultset('Users')->find(params->{id});
-        template user_profile => { user => $user };
-    };
-
-    dance;
 
 Database connection details are read from your Dancer application config - see
 below.
 
 =head1 DESCRIPTION
 
-Provides an easy way to obtain DBIx::Class::ResultSet instances.
+This plugin provides an easy way to obtain L<DBIx::Class::ResultSet> instances
+via the the function schema(), which it automatically imports.
 You just need to point to a dsn in your L<Dancer> configuration file.
 So you no longer have to write boilerplate DBIC setup code.
 
 =head1 CONFIGURATION
 
-Connection details will be taken from your Dancer application config file, and
-should be specified as stated above, for example: 
+Connection details will be grabbed from your L<Dancer> config file.
+For example: 
 
     plugins:
       DBIC:
         foo:
-          schema_class: "Foo::Bar"
-          dsn:  "dbi:mysql:db_foo"
-          user: "root"
-          pass: "****"
+          dsn: dbi:SQLite:dbname=./foo.db
+        bar:
+          schema_class: Foo::Bar
+          dsn:  dbi:mysql:db_foo
+          user: root
+          pass: secret
           options:
             RaiseError: 1
             PrintError: 1
-        bar:
-          dsn:  "dbi:SQLite:dbname=./foo.db"
 
-Make sure that the options immediately under DBIC
-(foo and bar in the above example)
-do not clash with existing L<Dancer> and Dancer::Plugin::*** reserved keywords. 
-
-Each database configuration *must* have a dsn option.
+Each schema configuration *must* have a dsn option.
 The dsn option should be the L<DBI> driver connection string.
+All other options are optional.
 
 If a schema_class option is not provided, then L<DBIx::Class::Schema::Loader>
-will be used to auto load the schema.
+will be used to auto load the schema based on the dsn value.
 
 The schema_class option, if provided, should be a proper Perl package name that
 Dancer::Plugin::DBIC will use as a DBIx::Class::Schema class.
 Optionally, a database configuation may have user, pass and options paramters
-which are appended to the dsn in list form,
-i.e. dbi:SQLite:dbname=./foo.db, $user, $pass, $options.
+as described in the documentation for connect() in L<DBI>.
 
     # Note! You can also declare your connection information with the
     # following syntax:
@@ -139,7 +132,7 @@ i.e. dbi:SQLite:dbname=./foo.db, $user, $pass, $options.
           connect_info:
             - dbi:mysql:db_foo
             - root
-            - ***
+            - secret
             -
               RaiseError: 1
               PrintError: 1
@@ -154,7 +147,7 @@ Al Newkirk <awncorp@cpan.org>
 
 =item *
 
-Naveed Massjouni <naveedm9@gmail.com>
+Naveed Massjouni <ironcamel@cpan.org>
 
 =back
 
